@@ -2,7 +2,7 @@ use std::io::{IoSlice, IoSliceMut};
 use std::net::SocketAddr;
 use std::pin::Pin;
 
-use smol::Async;
+use async_io::Async;
 
 use crate::io::{self, Read, Write};
 use crate::net::ToSocketAddrs;
@@ -71,13 +71,11 @@ impl TcpStream {
     /// # Ok(()) }) }
     /// ```
     pub async fn connect<A: ToSocketAddrs>(addrs: A) -> io::Result<TcpStream> {
-        once_cell::sync::Lazy::force(&crate::rt::RUNTIME);
-
         let mut last_err = None;
         let addrs = addrs.to_socket_addrs().await?;
 
         for addr in addrs {
-            match Async::<std::net::TcpStream>::connect(&addr).await {
+            match Async::<std::net::TcpStream>::connect(addr).await {
                 Ok(stream) => {
                     return Ok(TcpStream {
                         watcher: Arc::new(stream),
@@ -309,6 +307,14 @@ impl Read for &TcpStream {
     ) -> Poll<io::Result<usize>> {
         Pin::new(&mut &*self.watcher).poll_read(cx, buf)
     }
+
+    fn poll_read_vectored(
+        self: Pin<&mut Self>,
+        cx: &mut Context<'_>,
+        bufs: &mut [IoSliceMut<'_>],
+    ) -> Poll<io::Result<usize>> {
+        Pin::new(&mut &*self.watcher).poll_read_vectored(cx, bufs)
+    }
 }
 
 impl Write for TcpStream {
@@ -346,6 +352,14 @@ impl Write for &TcpStream {
         Pin::new(&mut &*self.watcher).poll_write(cx, buf)
     }
 
+    fn poll_write_vectored(
+        self: Pin<&mut Self>,
+        cx: &mut Context<'_>,
+        bufs: &[IoSlice<'_>],
+    ) -> Poll<io::Result<usize>> {
+        Pin::new(&mut &*self.watcher).poll_write_vectored(cx, bufs)
+    }
+
     fn poll_flush(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<io::Result<()>> {
         Pin::new(&mut &*self.watcher).poll_flush(cx)
     }
@@ -358,8 +372,6 @@ impl Write for &TcpStream {
 impl From<std::net::TcpStream> for TcpStream {
     /// Converts a `std::net::TcpStream` into its asynchronous equivalent.
     fn from(stream: std::net::TcpStream) -> TcpStream {
-        once_cell::sync::Lazy::force(&crate::rt::RUNTIME);
-
         TcpStream {
             watcher: Arc::new(Async::new(stream).expect("TcpStream is known to be good")),
         }
