@@ -2,7 +2,7 @@ use std::io;
 use std::net::SocketAddr;
 use std::net::{Ipv4Addr, Ipv6Addr};
 
-use smol::Async;
+use async_io::Async;
 
 use crate::net::ToSocketAddrs;
 use crate::utils::Context as _;
@@ -68,13 +68,11 @@ impl UdpSocket {
     /// # Ok(()) }) }
     /// ```
     pub async fn bind<A: ToSocketAddrs>(addrs: A) -> io::Result<UdpSocket> {
-        once_cell::sync::Lazy::force(&crate::rt::RUNTIME);
-
         let mut last_err = None;
         let addrs = addrs.to_socket_addrs().await?;
 
         for addr in addrs {
-            match Async::<std::net::UdpSocket>::bind(&addr) {
+            match Async::<std::net::UdpSocket>::bind(addr) {
                 Ok(socket) => {
                     return Ok(UdpSocket { watcher: socket });
                 }
@@ -206,6 +204,29 @@ impl UdpSocket {
         self.watcher.recv_from(buf).await
     }
 
+    /// Receives data from socket without removing it from the queue.
+    ///
+    /// On success, returns the number of bytes peeked and the origin.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// # fn main() -> std::io::Result<()> { async_std::task::block_on(async {
+    /// #
+    /// use async_std::net::UdpSocket;
+    ///
+    /// let socket = UdpSocket::bind("127.0.0.1:0").await?;
+    ///
+    /// let mut buf = vec![0; 1024];
+    /// let (n, peer) = socket.peek_from(&mut buf).await?;
+    /// println!("Peeked {} bytes from {}", n, peer);
+    /// #
+    /// # Ok (()) }) }
+    /// ```
+    pub async fn peek_from(&self, buf: &mut [u8]) -> io::Result<(usize, SocketAddr)> {
+        self.watcher.peek_from(buf).await
+    }
+
     /// Connects the UDP socket to a remote address.
     ///
     /// When connected, methods [`send`] and [`recv`] will use the specified address for sending
@@ -301,6 +322,30 @@ impl UdpSocket {
         self.watcher.recv(buf).await
     }
 
+    /// Receives data from the socket without removing it from the queue.
+    ///
+    /// On success, returns the number of bytes peeked.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// # fn main() -> std::io::Result<()> { async_std::task::block_on(async {
+    /// #
+    /// use async_std::net::UdpSocket;
+    ///
+    /// let socket = UdpSocket::bind("127.0.0.1:0").await?;
+    /// socket.connect("127.0.0.1:8080").await?;
+    ///
+    /// let mut buf = vec![0; 1024];
+    /// let n = socket.peek(&mut buf).await?;
+    /// println!("Peeked {} bytes", n);
+    /// #
+    /// # Ok(()) }) }
+    /// ```
+    pub async fn peek(&self, buf: &mut [u8]) -> io::Result<usize> {
+        self.watcher.peek(buf).await
+    }
+
     /// Gets the value of the `SO_BROADCAST` option for this socket.
     ///
     /// For more information about this option, see [`set_broadcast`].
@@ -481,8 +526,6 @@ impl UdpSocket {
 impl From<std::net::UdpSocket> for UdpSocket {
     /// Converts a `std::net::UdpSocket` into its asynchronous equivalent.
     fn from(socket: std::net::UdpSocket) -> UdpSocket {
-        once_cell::sync::Lazy::force(&crate::rt::RUNTIME);
-
         UdpSocket {
             watcher: Async::new(socket).expect("UdpSocket is known to be good"),
         }
@@ -506,7 +549,7 @@ cfg_unix! {
 
     impl IntoRawFd for UdpSocket {
         fn into_raw_fd(self) -> RawFd {
-            self.watcher.into_raw_fd()
+            self.watcher.into_inner().unwrap().into_raw_fd()
         }
     }
 }
@@ -530,7 +573,7 @@ cfg_windows! {
 
     impl IntoRawSocket for UdpSocket {
         fn into_raw_socket(self) -> RawSocket {
-            self.watcher.into_raw_socket()
+            self.watcher.into_inner().unwrap().into_raw_socket()
         }
     }
 }
